@@ -43,8 +43,6 @@ import shutil
 import tempfile
 import traceback
 
-import notifier
-import notifier.threads
 import six
 from ldap import INVALID_CREDENTIALS, LDAPError
 from six.moves.urllib_error import HTTPError, URLError
@@ -64,7 +62,8 @@ from univention.management.console.ldap import get_user_connection
 from univention.management.console.log import MODULE
 from univention.management.console.modules import Base, UMC_Error
 from univention.management.console.modules.decorators import (
-    allow_get_request, file_upload, multi_response, prevent_xsrf_check, sanitize, simple_response, threaded,
+    SimpleThread, allow_get_request, file_upload, multi_response, prevent_xsrf_check, sanitize, simple_response,
+    threaded,
 )
 from univention.management.console.modules.mixins import ProgressMixin
 from univention.management.console.modules.sanitizers import (
@@ -171,12 +170,18 @@ class Instance(Base, ProgressMixin):
         self.__license_checks = set()
         install_opener(ucr)
 
-    def init(self):
-        if not self.user_dn:
-            raise UserWithoutDN(self._username)
+    def prepare(self, request):
+        super(Instance, self).prepare(request)
+        if not request.user_dn:
+            raise UserWithoutDN(request.username)
 
-        MODULE.info('Initializing module as user %r' % (self.user_dn,))
-        set_bind_function(self.bind_user_connection)
+        MODULE.info('Initializing module as user %r' % (request.user_dn,))
+
+        def bind_user_connection(lo):
+            request.bind_user_connection(lo)
+            self.require_license(lo)
+
+        set_bind_function(bind_user_connection)
 
         # read user settings and initial UDR
         self.reports_cfg = udr.Config()
@@ -194,10 +199,6 @@ class Instance(Base, ProgressMixin):
         if isinstance(exc, (udm_errors.base, LDAPError)):
             MODULE.error(''.join(traceback.format_exception(etype, exc, etraceback)))
 
-    def bind_user_connection(self, lo):
-        super(Instance, self).bind_user_connection(lo)
-        self.require_license(lo)
-
     def require_license(self, lo):
         if id(lo) in self.__license_checks:
             return
@@ -507,7 +508,7 @@ class Instance(Base, ProgressMixin):
         result = []
         for ldap_dn in request.options:
             if request.flavor == 'users/self':
-                ldap_dn = self._user_dn
+                ldap_dn = request.user_dn
             obj, module = self.get_obj_module(request.flavor, ldap_dn)
             if module is None:
                 raise ObjectDoesNotExist(ldap_dn)
@@ -1128,8 +1129,8 @@ class Instance(Base, ProgressMixin):
 
             return entries
 
-        thread = notifier.threads.Simple('NavObjectQuery', notifier.Callback(_thread, request.options['container']), notifier.Callback(self.thread_finished_callback, request))
-        thread.run()
+        thread = SimpleThread('NavObjectQuery', _thread, lambda r, t: self.thread_finished_callback(r, t, request))
+        thread.run(request.options['container'])
 
     @sanitize(DictSanitizer({
         "objectType": StringSanitizer(required=True),
